| barry-package | R Documentation |
Provides 'C++' header-only files for the 'barry' library, which is a template library for counting sufficient statistics on binary arrays and building discrete exponential-family models. The 'barry' library includes tools for sparse arrays, user-defined count statistics, support set constraints, power set generation, and modules for Discrete Exponential Family Models (DEFMs) and network statistics.
This package follows the same approach as the 'BH' package which provides
'Boost' headers for R. To use 'barry' in your R package, add LinkingTo: barry
to your DESCRIPTION file. The headers will then be available for inclusion
in your 'C++' code via #include <barry/barry.hpp>.
The 'barry' library was created by Dr. George G. Vega Yon as part of his doctoral dissertation and provides a general framework for building discrete exponential-family models, particularly useful for Exponential Random Graph Models (ERGMs) and other network statistics.
Maintainer: George Vega Yon g.vegayon@gmail.com (ORCID)
Other contributors:
U.S. Army Medical Research Acquisition Activity (ORION project, Award #W81XWH1910615) [funder]
National Cancer Institute (IMAGE project, Grant #1P01CA196596) [funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.